@@ -540,6 +540,19 @@ class recset(Generic[T]):
         self.__currentRowIndex += 1
 
         return False if len(self.__rows) > self.__currentRowIndex else True
+
+    def nexteof(self):
+        
+        """
+        次レコードの行情報有無を返す
+        
+        Parameters
+        ----------
+        None
+        
+        """
+
+        return False if len(self.__rows) > self.__currentRowIndex + 1 else True
     
     def getDataFrame(self, __rows = None):
         
